@@ -34,7 +34,7 @@ class Speciality(Base):
 
     def __repr__(self):
         return "<Speciality {}>".format(self)
-    
+
     def __str__(self):
         return "{} - {}".format(self.code, self.name_ru)
 
@@ -46,14 +46,15 @@ class SpecialityChair(Base):
 
     __tablename__ = 'univer_speciality_chair'
 
-    speciality_id = Column(ForeignKey('univer_speciality.speciality_id'), primary_key=True)
+    speciality_id = Column(ForeignKey(
+        'univer_speciality.speciality_id'), primary_key=True)
     speciality = relationship('Speciality')
     chair_id = Column(ForeignKey('univer_chair.chair_id'), primary_key=True)
     chair = relationship('Chair')
 
     def __repr__(self):
         return '<SpecialityChair {}>'.format(self)
-    
+
     def __str__(self):
         return '{} - {}'.format(self.chair, self.speciality)
 
@@ -76,7 +77,7 @@ class Subject(Base):
 
     def __repr__(self):
         return '<Subject {}>'.format(self.name_ru)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -106,7 +107,7 @@ class LangDivision(Base):
 
     def __repr__(self):
         return '<LangDivision {}>'.format(self.name_ru)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -126,7 +127,7 @@ class DocumentIdentity(Base):
 
     def __repr__(self):
         return '<DocumentIdentity {} (id={})'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -146,7 +147,7 @@ class Institution(Base):
 
     def __repr__(self):
         return '<Institution {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -166,7 +167,7 @@ class GraduateDocType(Base):
 
     def __repr__(self):
         return '<GraduateDocType {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -184,14 +185,16 @@ class GraduateInfo(Base):
     institution_name = Column('graduate_info_institution_name', String)
     series = Column('graduate_info_series', String)
     number = Column('graduate_info_number', String)
-    graduate_doctype_id = Column(ForeignKey('univer_graduate_doctypes.graduate_doctype_id'))
+    graduate_doctype_id = Column(ForeignKey(
+        'univer_graduate_doctypes.graduate_doctype_id'))
     graduate_doctype = relationship('GraduateDocType')
-    institution_id = Column('edu_institution_id', ForeignKey('univer_edu_institutions.edu_institution_id'))
+    institution_id = Column('edu_institution_id', ForeignKey(
+        'univer_edu_institutions.edu_institution_id'))
     institution = relationship('Institution')
 
     def __repr__(self):
         return '<Graduate {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return '{} {}'.format(self.series, self.number)
 
@@ -208,12 +211,13 @@ class Contract(Base):
     number = Column('contract_number', String)
     date_received = Column('contract_date_recieved', DateTime)
     status = Column(Integer)
-    student_id = Column('students_id', ForeignKey('univer_students.students_id'))
+    student_id = Column('students_id', ForeignKey(
+        'univer_students.students_id'))
     student = relationship('Student')
 
     def __repr__(self):
         return '<Contract {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         '{} ({})'.format(self.student, self.number)
 
@@ -238,7 +242,7 @@ class AcademCalendar(Base):
 
     def __repr__(self):
         return '<AcademCalendar {}>'.format(self)
-    
+
     def __str__(self):
         return '{}'.format(self.id)
 
@@ -247,42 +251,56 @@ class EducPlan(Base):
     """
     Модель "Учебный план"
     """
-
     __tablename__ = 'univer_educ_plan'
 
+    # Идентификатор
     id = Column('educ_plan_id', Integer, primary_key=True)
-    speciality_id = Column('speciality_id', ForeignKey('univer_speciality.speciality_id'))
+
+    # Специальность
+    speciality_id = Column('speciality_id', ForeignKey(
+        'univer_speciality.speciality_id'))
     speciality = relationship('Speciality')
-    education_form_id = Column(ForeignKey('univer_education_form.education_form_id'))
+
+    # Форма обучения
+    education_form_id = Column(ForeignKey(
+        'univer_education_form.education_form_id'))
     education_form = relationship('EducationForm')
+
+    # Уровень образования
     edu_level_id = Column(ForeignKey('univer_edu_levels.edu_level_id'))
     edu_level = relationship('EduLevel')
+
+    # Учебный год
     year = Column('educ_plan_adm_year', Integer)
-    semesters = Column('educ_plan_number_of_semestr', Integer)  # Количество семестров в учебном плане
+
+    # Количество семестров в учебном плане
+    semesters = Column('educ_plan_number_of_semestr', Integer)
+
+    # Количество обязательных кредитов
+    min_cred_total = Column('educ_plan_min_cred_total', Integer)
 
     # Статус
     status = Column(Integer)
 
     def __repr__(self):
         return "<EducPlan {} {}>".format(self.speciality, self.year)
-    
+
     def __str__(self):
         return "{} {}".format(self.speciality, self.year)
 
 
 class EducPlanPos(Base):
     """
-    Модель "Позиции учебного плана"
-    Статус: Выполняется
+    Модель "Позиция учебного плана"
     """
-
     __tablename__ = 'univer_educ_plan_pos'
 
     # Идентификатор
     id = Column('educ_plan_pos_id', Integer, primary_key=True)
 
     # Учебный план
-    educ_plan_id = Column('educ_plan_id', ForeignKey('univer_educ_plan.educ_plan_id'))
+    educ_plan_id = Column('educ_plan_id', ForeignKey(
+        'univer_educ_plan.educ_plan_id'))
     educ_plan = relationship('EducPlan')
 
     # Код дисциплины
@@ -293,22 +311,51 @@ class EducPlanPos(Base):
     subject = relationship('Subject')
 
     # Тип контроля
-    controll_type_id = Column(ForeignKey('univer_controll_type.controll_type_id'))
+    controll_type_id = Column(ForeignKey(
+        'univer_controll_type.controll_type_id'))
     controll_type = relationship('ControllType')
 
+    # Кредит
+    credit = Column('educ_plan_pos_credit', Integer)
+
     # Семестр
     semester = Column('educ_plan_pos_semestr', Integer)
 
+    # Цикл
+    cycle_id = Column(ForeignKey('univer_cycles.cycle_id'))
+    cycle = relationship('Cycle')
+
     # Статус
     status = Column(Integer)
 
     def __repr__(self):
         return "<EducPlanPos {}: {} ({} семестр)>".format(self.educ_plan, self.subject, self.semester)
-    
+
     def __str__(self):
         return "{}: {} ({} семестр)".format(self.educ_plan, self.subject, self.semester)
 
 
+class Cycle(Base):
+    """
+    Модель "Цикл"
+    """
+    __tablename__ = 'univer_cycles'
+
+    # Идентификатор
+    id = Column('cycle_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('cycle_name_ru', String)
+    name_kz = Column('cycle_name_kz', String)
+    name_en = Column('cycle_name_en', String)
+
+    def __repr__(self):
+        return '<Cycle {}>'.format(self)
+
+    def __str__(self):
+        return self.name_ru
+
+
 class Attendance(Base):
     """
     Модель "Журнал посещаемости"
@@ -319,14 +366,15 @@ class Attendance(Base):
     date = Column('att_date', Date, primary_key=True)
     grade = Column('ball', Float)
     was = Column(Boolean)
-    student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
+    student_id = Column(ForeignKey(
+        'univer_students.students_id'), primary_key=True)
     student = relationship('Student')
     group_id = Column(ForeignKey('univer_group.group_id'), primary_key=True)
     group = relationship('Group')
 
     def __repr__(self):
         return '<Attendance {}: {} балл ({})>'.format(self.student, self.grade, self.date)
-    
+
     def __str__(self):
         return '{}: {} балл ({})'.format(self.student, self.grade, self.date)
 
@@ -340,16 +388,19 @@ class Group(Base):
     __tablename__ = 'univer_group'
 
     id = Column('group_id', Integer, primary_key=True)
-    educ_plan_pos_id = Column('educ_plan_pos_id', ForeignKey('univer_educ_plan_pos.educ_plan_pos_id'))
+    educ_plan_pos_id = Column('educ_plan_pos_id', ForeignKey(
+        'univer_educ_plan_pos.educ_plan_pos_id'))
     educ_plan_pos = relationship('EducPlanPos', backref='groups')
     teacher_id = Column('teacher_id', ForeignKey('univer_teacher.teacher_id'))
     teacher = relationship('Teacher')
     year = Column('group_year', Float)
     semester = Column('group_semestr', Integer)
     acpos_module = Column('acpos_module', Integer)
-    educ_type_id = Column('educ_type_id', ForeignKey('univer_educ_type.educ_type_id'))
+    educ_type_id = Column('educ_type_id', ForeignKey(
+        'univer_educ_type.educ_type_id'))
     educ_type = relationship('EducType')
-    lang_division_id = Column('lang_division_id', ForeignKey('univer_lang_division.lang_division_id'))
+    lang_division_id = Column('lang_division_id', ForeignKey(
+        'univer_lang_division.lang_division_id'))
     lang_division = relationship('LangDivision')
 
     # Семестр повторного обучения
@@ -357,7 +408,7 @@ class Group(Base):
 
     def __repr__(self):
         return '<Group {} (id={} educ_plan_pos_id={} teacher_id={})>'.format(self, self.id, self.educ_plan_pos_id, self.teacher_id)
-    
+
     def __str__(self):
         return '{} ({} год)'.format(self.educ_plan_pos.educ_plan.speciality, self.educ_plan_pos.educ_plan.year)
 
@@ -388,11 +439,10 @@ class Controll(Base):
 
     # Наименование
     name_ru = Column('control_name_ru', String(100))
-    
 
     def __repr__(self):
         return '<Controll {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -414,7 +464,7 @@ class ControllType(Base):
 
     def __repr__(self):
         return '<ControllType {}>'.format(self)
-    
+
     def __str__(self):
         return self.name_ru
 
@@ -428,20 +478,23 @@ class ControllTypeControllLink(Base):
     __tablename__ = 'univer_controll_type_control_link'
 
     # Тип контроля
-    controll_type_id = Column(ForeignKey('univer_controll_type.controll_type_id'), primary_key=True)
+    controll_type_id = Column(ForeignKey(
+        'univer_controll_type.controll_type_id'), primary_key=True)
     controll_type = relationship('ControllType')
 
     # Контроль
-    controll_id = Column('control_id', ForeignKey('univer_control.control_id'), primary_key=True)
+    controll_id = Column('control_id', ForeignKey(
+        'univer_control.control_id'), primary_key=True)
     controll = relationship('Controll')
 
     # Тип ведомости
-    sheet_type_id = Column(ForeignKey('univer_sheet_type.sheet_type_id'), primary_key=True)
+    sheet_type_id = Column(ForeignKey(
+        'univer_sheet_type.sheet_type_id'), primary_key=True)
     sheet_type = relationship('SheetType')
 
     def __repr__(self):
         return '<ControllTypeControllLink {} (controll_type_id={} controll_id={} sheet_type_id={}>'.format(self, self.controll_type_id, self.controll_id, self.sheet_type_id)
-    
+
     def __str__(self):
         return '{}-{}'.format(self.controll_type, self.controll)
 
@@ -520,7 +573,8 @@ class Progress(Base):
     semester = Column('n_seme', Integer)
 
     # Тип контроля
-    controll_type_id = Column(ForeignKey('univer_controll_type.controll_type_id'))
+    controll_type_id = Column(ForeignKey(
+        'univer_controll_type.controll_type_id'))
     controll_type = relationship('ControllType')
 
     # Часы
@@ -531,7 +585,7 @@ class Progress(Base):
 
     def __repr__(self):
         return '<Progress {}>'.format(self)
-    
+
     def __str__(self):
         return '{} - {}'.format(self.student, self.subject)
 
@@ -551,6 +605,6 @@ class Country(Base):
 
     def __repr__(self):
         return '<Country {}>'.format(self)
-    
+
     def __str__(self):
         return self.name_ru
