@@ -324,6 +324,29 @@ class OfficeRegistrator(Base):
         return str(self.personnel)
 
 
+class OfficeRegistratorFacultyLink(Base):
+    """
+    Связь между Специалистом ОР и Факультетом
+    """
+    __tablename__ = 'univer_office_registrator_faculty_link'
+
+    # Специалист ОР
+    office_registrator_id = Column(ForeignKey(
+        'univer_office_registrator.office_registrator_id'), primary_key=True)
+    office_registrator = relationship('OfficeRegistrator')
+
+    # Факультет
+    faculty_id = Column(ForeignKey(
+        'univer_faculty.faculty_id'), primary_key=True)
+    faculty = relationship('Faculty')
+
+    def __repr__(self):
+        return '<OfficeRegistratorFacultyLink {}>'.format(self)
+
+    def __str__(self):
+        return f'{self.office_registrator}: {self.faculty}'
+
+
 class Dean(Base):
     """
     Модель "Декан"
@@ -365,7 +388,8 @@ class TeacherChairLink(Base):
     __tablename__ = 'univer_teacher_chair_link'
 
     # Преподаватель
-    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'), primary_key=True)
+    teacher_id = Column(ForeignKey(
+        'univer_teacher.teacher_id'), primary_key=True)
     teacher = relationship('Teacher')
 
     # Кафедра
